####################
更新履歴
####################

***********
v2.0.0a3
***********

Breaking Changes
===================

* :code:`Experiment`, :code:`Plotter` クラスを廃止しました。

    * これらが利用可能なバージョンを v1.2.0 としてリリースしました。必要であればこちらを利用してください。

Features
===================

* 新しい実験定義のインタフェースを実装しました。
* tkinterによるGUIサポートを追加しました。

Bug Fixes
===================

* pyvisa_device のデストラクタにおいて、接続を切断してしまうバグを修正しました。


***********
v2.0.0a2
***********

Bug Fixes
===================

* 実験のファイル保存時のcsvのカラムが正常にならないバグを修正しました。


***********
v2.0.0a1
***********

Breaking Changes
===================

* フォルダ探索の際に、 :code:`ebilab.ini` ファイルを探索するように変更しました。
* :code:`ebilab.experiment.core` モジュールが廃止されました。互換性のためにしばらくは残されますが、

  .. code-block:: python

      from ebilab.experiment import Plotter, Experiment

  を使用してください。

Features
===================

* :code:`ebilab init` コマンドでプロジェクトテンプレートからのプロジェクト作成ができるようになりました。


***********
v2.0.0a0
***********

Breaking Changes
===================

* いくつかのデバイスの測定メソッドで、オプションをenumではなくstringで指定するようになりました。

Features
===================

* :py:func:`E4980.trigger() <ebilab.experiment.devices.E4980.trigger()>` メソッドで出力フォーマットを指定できるようになりました。


